@@ -172,7 +172,7 @@ class BmaClient(AbstractClient):
 
 
     def CreateCRBlock(self, request):
-        """版权保护-新建拦截接口
+        """新建拦截
 
         :param request: Request instance for CreateCRBlock.
         :type request: :class:`tencentcloud.bma.v20210624.models.CreateCRBlockRequest`
@@ -201,7 +201,7 @@ class BmaClient(AbstractClient):
 
 
     def CreateCRCompanyVerify(self, request):
-        """品牌经营管家-版权保护模块企业认证接口
+        """本接口用于企业认证，新接入用户必须认证后才可以进行后续操作（个人认证和企业认证二选一），只需认证一次即可
 
         :param request: Request instance for CreateCRCompanyVerify.
         :type request: :class:`tencentcloud.bma.v20210624.models.CreateCRCompanyVerifyRequest`
@@ -258,8 +258,66 @@ class BmaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateCRRightFile(self, request):
+        """权属文件添加
+
+        :param request: Request instance for CreateCRRightFile.
+        :type request: :class:`tencentcloud.bma.v20210624.models.CreateCRRightFileRequest`
+        :rtype: :class:`tencentcloud.bma.v20210624.models.CreateCRRightFileResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCRRightFile", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateCRRightFileResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateCRTort(self, request):
+        """举报侵权链接
+
+        :param request: Request instance for CreateCRTort.
+        :type request: :class:`tencentcloud.bma.v20210624.models.CreateCRTortRequest`
+        :rtype: :class:`tencentcloud.bma.v20210624.models.CreateCRTortResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCRTort", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateCRTortResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateCRUserVerify(self, request):
-        """品牌经营管家-版权保护个人认证接口
+        """本接口用于个人认证，新接入用户必须认证后才可以进行后续操作（个人认证和企业认证二选一），只需认证一次即可
 
         :param request: Request instance for CreateCRUserVerify.
         :type request: :class:`tencentcloud.bma.v20210624.models.CreateCRUserVerifyRequest`
@@ -288,7 +346,7 @@ class BmaClient(AbstractClient):
 
 
     def CreateCRWork(self, request):
-        """版权保护-添加作品接口
+        """新建作品
 
         :param request: Request instance for CreateCRWork.
         :type request: :class:`tencentcloud.bma.v20210624.models.CreateCRWorkRequest`
@@ -549,7 +607,7 @@ class BmaClient(AbstractClient):
 
 
     def ModifyCRBlockStatus(self, request):
-        """版权保护-拦截申请接口
+        """拦截申请
 
         :param request: Request instance for ModifyCRBlockStatus.
         :type request: :class:`tencentcloud.bma.v20210624.models.ModifyCRBlockStatusRequest`
@@ -578,7 +636,7 @@ class BmaClient(AbstractClient):
 
 
     def ModifyCRMonitor(self, request):
-        """版权保护-修改监测状态接口
+        """开启/关闭监测
 
         :param request: Request instance for ModifyCRMonitor.
         :type request: :class:`tencentcloud.bma.v20210624.models.ModifyCRMonitorRequest`
@@ -607,7 +665,7 @@ class BmaClient(AbstractClient):
 
 
     def ModifyCRObtainStatus(self, request):
-        """申请取证
+        """取证申请
 
         :param request: Request instance for ModifyCRObtainStatus.
         :type request: :class:`tencentcloud.bma.v20210624.models.ModifyCRObtainStatusRequest`
@@ -636,7 +694,7 @@ class BmaClient(AbstractClient):
 
 
     def ModifyCRRightStatus(self, request):
-        """版权保护-维权申请接口
+        """发函申请
 
         :param request: Request instance for ModifyCRRightStatus.
         :type request: :class:`tencentcloud.bma.v20210624.models.ModifyCRRightStatusRequest`
@@ -664,6 +722,35 @@ class BmaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyCRWhiteList(self, request):
+        """修改白名单列表
+
+        :param request: Request instance for ModifyCRWhiteList.
+        :type request: :class:`tencentcloud.bma.v20210624.models.ModifyCRWhiteListRequest`
+        :rtype: :class:`tencentcloud.bma.v20210624.models.ModifyCRWhiteListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyCRWhiteList", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyCRWhiteListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateCRWork(self, request):
         """更新作品
 
